@@ -81,6 +81,23 @@ function executeCommands(pythonProcess, data, globalStorage) {
       }
       pythonProcess.stdin.write(JSON.stringify(res) + "\n");
       break;
+    case "EE":
+      let { start, end } = JSON.parse(args[0]);
+      let range = new vscode.Range(
+        start.line,
+        start.character,
+        end.line,
+        end.character
+      );
+      if (!vscode.window.activeTextEditor) {
+        return;
+      }
+      vscode.window.activeTextEditor
+        .edit((editB) => {
+          editB.replace(range, args[1]);
+        })
+        .then((s) => pythonProcess.stdin.write(s + "\n"));
+      break;
     default:
       console.log("Couldn't parse this: " + data);
   }
